@@ -2,23 +2,23 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_gpgcheckfiles.pl,v 1.3 2005/06/28 16:11:15 yeupou Exp $
+# $Id: sv_gpgcheckfiles.pl,v 1.5 2005/07/04 08:09:26 yeupou Exp $
 #
 #  Copyright 2005      (c) Mathieu Roy <yeupou--gnu.org> 
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #
 ##
 ## This script should be used via a cronjob to check if files in a download
@@ -207,7 +207,6 @@ if (-e $cachefile && ! $nocache) {
 }
 
 
-
 #####################################################################
 #####################################################################
 # Get the list of active projects
@@ -222,6 +221,28 @@ foreach my $line (GetDB("groups",
 print LOG strftime "[$script] %c - database infos grabbed\n", localtime;
 
 
+#####################################################################
+#####################################################################
+# Get the gid according to the chroot, if inside the chroot.
+# We'll maybe need that information for chown calls.
+my %project_gid;
+if ($chroot) {
+    # We cannot use getgrent since we have to grab data inside the chroot and
+    # since chroot() would not allow use to get out of it.
+    # One option could be to call a specific script for that but it's easier 
+    # to directly read $chroot/etc/group.
+    # Indeed, it may not be very portable.
+    open(GROUP, "< $chroot/etc/group");
+    while (<GROUP>) {
+	my ($name, $mark, $id) = split(":", $_);
+	next unless $db_groups{$name};
+	$project_gid{$name} = $id;
+    }
+    close(GROUP);
+    print LOG strftime "[$script] %c - $chroot/etc/group infos grabbed\n", localtime;
+}
+
+
 #####################################################################
 #####################################################################
 # First look, first impression, find out project directories status :
@@ -415,7 +436,7 @@ While you should assume these files are clean, truly from the project <a href="'
 
     # Depending on modes of dirs, new files may not belong to root.
     # Make sure it is by brute force
-    system("chown", "root.root", $header);
+    system("chown", "root:root", $header);
 
     print LOG strftime "[$script] %c ----  *nothing signed* for $project\n", localtime;
   
@@ -524,7 +545,7 @@ Questionable files have been moved in the subdirectory /maybe-corrupted. But you
 
 	# Depending on modes of dirs, new files may not belong to root.
 	# Make sure it is by brute force
-	system("chown", "root.root", $header);	
+	system("chown", "root:root", $header);	
 
 	print LOG strftime "[$script] %c ----  $header written\n", localtime;
 	
@@ -541,7 +562,15 @@ These files as been stored here so members of the project <a href="'.$basepath.'
 	    
 	    # Content of maybe corrupted should belong to the project, so they
 	    # can clean it
-	    system("chown", "root.".$project, "$directory/maybe-corrupted");
+	    
+	    # We must find out the gid of the group according to the chroot
+	    # (we cannot call chroot directly because people are free to use
+	    # a --dir that is in fact outside the --chroot)
+	    # This is done first, and only if --chroot is set.
+	    # If chroot is not set, we'll use the group name.
+	    $project_gid{$project} = $project unless $chroot;
+	    
+	    system("chown", "root:".$project_gid{$project}, "$directory/maybe-corrupted");
 	    system("chmod", "g+rw", "$directory/maybe-corrupted");
 	    
 	    print LOG strftime "[$script] %c ----  $directory/maybe-corrupted/HEADER.html written\n", localtime;
