@@ -2,27 +2,27 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: features_boxes.php,v 1.48 2005/04/06 19:56:12 toddy Exp $
+# $Id: features_boxes.php,v 1.50 2005/08/31 21:05:09 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 
 function show_features_boxes()
@@ -30,14 +30,41 @@ function show_features_boxes()
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_features_boxes() ';
   GLOBAL $HTML;
 
+  #### General Stats
+
   $return .= $HTML->box_top(utils_link($GLOBALS['sys_home']."stats/", sprintf(_("%s Statistics"),$GLOBALS['sys_name']),"sortbutton"));
 
   $return .= show_sitestats();
   $return .= $HTML->box_bottom();
 
+
+  #### Job offers Stats
+  $jobs = people_show_category_list();
+  
+  if ($jobs)
+    {
+      $return .= "<br />\n";
+      $return .= $HTML->box_top(_("Help Wanted"),'',1);
+      $return .= $jobs;
+      $return .= $HTML->box_bottom(1);
+    }
+
+  
+  ### Popular items
+  $votes = show_votes();
+  
+  if ($votes)
+    {
+      $return .= "<br />\n";
+      $return .= $HTML->box_top(_("Most Popular Items"),'',1);
+      $return .= $votes;
+      $return .= $HTML->box_bottom(1);
+    }
+   
+
+  #### Group Type Stats
+
   $result = db_query("SELECT type_id,name FROM group_type ORDER BY type_id");
-
-
   # try to find out how many latest registered groups per group type
   # we should print, depending on how many groups we have.
   $limit = 10;
@@ -135,5 +162,83 @@ function show_newest_projects($group_type, $limit)
   return $return;
 }
 
+function show_votes ($limit=10)
+{
+  # Find out interesting bugs and store them in a hash
+  # Closed and private items are ignored.
+  $trackers = array("bugs", "task", "support", "patch");
+
+  $item_vote = array();
+  $item_summary = array();
+  # not enough space!
+  #$item_group_id = array();
+  
+  while (list(,$tracker) = each($trackers)) 
+    {
+      $sql = "SELECT bug_id,group_id,summary,vote FROM $tracker WHERE vote >=35 AND privacy=1 AND status_id=1 ORDER BY vote DESC LIMIT $limit";
+      
+      $result=db_query($sql);
+      $rows=db_numrows($result);
+      if ($result && $rows > 0)
+	{
+	  $results = 1;
+	  for ($j=0; $j<$rows; $j++)
+	    {
+
+              # Create item unique name
+	      $thisitem = $tracker.'#'.db_result($result,$j,'bug_id');
+      
+              # Store data
+	      $item_vote[$thisitem] = db_result($result,$j,'vote');
+	      $item_summary[$thisitem] = db_result($result,$j,'summary');
+              # not enough space!
+	      #$item_group_id[$thisitem] = db_result($result,$j,'group_id');
+	      
+	    }
+	}
+    }
+
+  # Break here if we have no results
+  if (!$results)
+    { return false; }
+
+  # Otherwise, sort items in rank and print the first 10 ones
+  unset($return, $count);
+  arsort($item_vote);
+  foreach ($item_vote as $thisitem => $vote) 
+    {
+      $count++;
+      if ($count > $limit) 
+	{ break; }
+      
+      list($tracker, $item_id) = explode("#", $thisitem);
+      $prefix = utils_get_tracker_prefix($tracker);
+      
+    
+      # if the summar item is large (>30), only show the first
+      # 30 characters of the story
+      if (strlen($item_summary[$thisitem]) > 30)
+	{
+	  $item_summary[$thisitem] = substr($item_summary[$thisitem], 0, 30);
+	  $item_summary[$thisitem] = substr($item_summary[$thisitem], 0, strrpos($item_summary[$thisitem], ' '));
+	  $item_summary[$thisitem] .= "...";
+	}
+
+      $return .= '<div class="'.utils_get_alt_row_color($count).'">'.
+	'<font class="smaller">&nbsp;&nbsp;- '.
+	'<a href="'.$GLOBALS['sys_home'].$tracker.'/?func=detailitem&amp;item_id='.$item_id.'">'.
+	$prefix .' #'.$item_id.'</a>'.
+	_(": ").'&nbsp;'.
+	'<a href="'.$GLOBALS['sys_home'].$tracker.'/?func=detailitem&amp;item_id='.$item_id.'">'.stripslashes($item_summary[$thisitem]).'</a>,'.
+	'&nbsp;<font class="smaller">'.sprintf(ngettext("%s vote", "%s votes", $vote), $vote).
+       # not enough space!
+       #', '.group_getname($item_group_id[$thisitem]).
+	'</font></font></div>';
+      
+    }
+  
+  return $return;
+}
+
 
 ?>
