@@ -2,25 +2,25 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.12 2005/04/11 21:38:02 toddy Exp $
+# $Id: general.php,v 1.14 2005/07/05 15:40:43 yeupou Exp $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
 #  Copyright 2003-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 
 function my_hide_url ($svc, $db_item_id, $item_id, $count, $hide, $link="")
@@ -92,12 +92,12 @@ Output:
 
   if ($hide)
     {
-      $hide_url= '<a href="'.$PHP_SELF.'?hide_'.$svc.'=0&amp;hide_group_id='.$db_item_id.'"><img src="'.$GLOBALS['sys_home'].'images/'. SV_THEME.'.theme/next.png" class="icon" alt="'._("Collapse").'" />'.$link.'</a>';
+      $hide_url= '<a name="'.$svc.$db_item_id.'" href="'.$PHP_SELF.'?hide_'.$svc.'=0&amp;hide_group_id='.$db_item_id.'#'.$svc.$db_item_id.'"><img src="'.$GLOBALS['sys_home'].'images/'. SV_THEME.'.theme/next.png" class="icon" alt="'._("Collapse").'" />'.$link.'</a>';
       $hide_now = true;
     }
   else
     {
-      $hide_url= '<a href="'.$PHP_SELF.'?hide_'.$svc.'=1&amp;hide_group_id='.$db_item_id.'"><img src="'.$GLOBALS['sys_home'].'images/'. SV_THEME.'.theme/down.png" class="icon" alt="'._("Expand").'" />'.$link.'</a>';
+      $hide_url= '<a name="'.$svc.$db_item_id.'" href="'.$PHP_SELF.'?hide_'.$svc.'=1&amp;hide_group_id='.$db_item_id.'#'.$svc.$db_item_id.'"><img src="'.$GLOBALS['sys_home'].'images/'. SV_THEME.'.theme/down.png" class="icon" alt="'._("Expand").'" />'.$link.'</a>';
       $hide_now = false;
     }
 
