@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: show.php,v 1.22 2005/04/11 13:15:51 toddy Exp $
+# $Id: show.php,v 1.25 2005/07/05 17:31:01 yeupou Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -10,19 +10,19 @@
 #  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 
 
@@ -240,7 +240,7 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
     {
       if ($rows > 15)
 	{ $rows = 15; }
-      $title = sprintf(_("%s latest changes"), $rows);
+      $title = sprintf(ngettext("%s latest change", "%s latest changes", $rows), $rows);
     }
 
 
@@ -357,10 +357,10 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
 }
 
 
-function show_item_details ($item_id, $group_id, $ascii=false, $item_assigned_to=false)
+function show_item_details ($item_id, $group_id, $ascii=false, $item_assigned_to=false,$quoted=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_item_details ($item_id, $group_id, $ascii=false)';
-  print format_item_details($item_id,$group_id,$ascii,$item_assigned_to);
+  print format_item_details($item_id,$group_id,$ascii,$item_assigned_to,$quoted);
 }
 
 
