@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod.php,v 1.27 2005/03/31 10:10:11 yeupou Exp $
+# $Id: mod.php,v 1.32 2005/09/01 13:13:53 toddy Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -10,19 +10,19 @@
 #  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 # Need search functions.
 require_directory("search");
@@ -136,6 +136,19 @@ print form_input("hidden", "item_id", $item_id);
           <td class="preinput">'._("Submitted on:").'&nbsp;</td><td>'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>
           <td colspan="6" align="center" valign="top"><input class="noprint" type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></td>
       </tr>';
+  
+  $votes = db_result($result,0,'vote');
+  if ($votes) 
+    {
+      # display vote here if any, anything else is handled below
+      print '
+      <tr>
+          <td class="preinput">'._("Votes:").'&nbsp;</td><td><a href="#votes">'.$votes.'</a></td>
+          <td>&nbsp;</td>
+      </tr>
+';
+
+    }
 
   $field_per_linex2=2*$fields_per_line;
   print '<tr><td colspan="'.$fields_per_linex2.'">&nbsp</td></tr>';
@@ -197,13 +210,12 @@ print form_input("hidden", "item_id", $item_id);
 	    }
 	  else
 	    {
-              $value = trackers_field_display($field_name,$group_id,$field_value,false,false,"","","","","","",true);
+              $value = trackers_field_display($field_name,$group_id,$field_value,false,false,$printer,false,false,_("None"),false,_("Any"),true);
 	    }
 
 
 	  $star = (trackers_data_is_empty_ok($field_name) ? '':'<font class="error"> *</font>');
 
-
 	  if ($sz > $max_size)
 	    {
 	      print "\n<tr>".
@@ -235,7 +247,10 @@ print form_input("hidden", "item_id", $item_id);
   print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br />';
-
+  if (trackers_data_is_used("vote"))
+    {
+      print '&nbsp;&nbsp;- <a href="#votes">'._("Votes").'</a><br />';
+    }
   if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
     {
       print '&nbsp;&nbsp;- <a href="#reassign">'._("Reassign this item").'</a><br />';
@@ -247,10 +262,24 @@ print form_input("hidden", "item_id", $item_id);
   # ################################ Comments
 
   print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3>';
+  print '<p class="noprint">';
+  printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"),
+	  "<font class=\"italic\">artifact #nnn</font>",
+	  "<font class=\"italic\">artifact</font>",
+	  "<font class=\"italic\">support, bug, task, patch</font>",
+	  "<font class=\"italic\">nnn</font>");
 
-  print '<table class="noprint">
-          <tr><td class="preinput">'
-    ._("Use a Canned Response:").'&nbsp;</td><td width="70%">';
+  print '<p class="noprint"><font class="preinput"> '._("Add a New Comment:").'</font><br />
+      &nbsp;&nbsp;&nbsp;';
+  print trackers_field_textarea('details',$details);
+  print '<p>';
+
+  print '<p class="noprint"><font class="preinput">';
+  print _("Comment Type:").'</font><br />&nbsp;&nbsp;&nbsp';
+  print trackers_field_box('comment_type_id',$comment_type_id,$group_id,'',true,'None');
+
+
+  print '<br /><font class="preinput">'._("Use a Canned Response:").'</font><br />&nbsp;&nbsp;&nbsp;';
 
   if ($canned_response == "!multiple!")
     {
@@ -263,7 +292,7 @@ print form_input("hidden", "item_id", $item_id);
 	    {
 
               print '<input type="checkbox" name="canned_response[]" value="'.$canned['bug_canned_id'].'" />'.$canned['title'];
-              print '<br />';
+              print '<br />&nbsp;&nbsp;&nbsp;';
 
 	    }
          }
@@ -277,28 +306,25 @@ print form_input("hidden", "item_id", $item_id);
     {
 
        print trackers_canned_response_box ($group_id,'canned_response');
-       print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&create_canned=1">['._("Or define a new Canned Response").']</a>';
+       print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&create_canned=1">('._("Or define a new Canned Response").')</a>';
 
     }
+   print '<br /><font class="preinput">'._("Previous Comment Style:").'</font><br />&nbsp;&nbsp;&nbsp;';
+  if ($quotation_style != "quoted") 
+   {
+      print '<input type="submit" name="change_quotation_style" value="'._("Quoted, ready to be copied/pasted into your new comment").'" />';
+   }
+  else 
+   {
+      print '<input type="submit" name="change_quotation_style" value="'._("Verbatim, unmodified").'" />';
 
-  print '</td></tr><tr><td class="preinput">';
-  print _("Comment Type:");
-  print '</td><td>';
-  print trackers_field_box('comment_type_id',$comment_type_id,$group_id,'',true,'None');
-  print '</td></tr></table>';
+   }
 
-  print '<p class="noprint">';
-  printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"),
-	  "<font class=\"italic\">artifact #nnn</font>",
-	  "<font class=\"italic\">artifact</font>",
-	  "<font class=\"italic\">support, bug, task, patch</font>",
-	  "<font class=\"italic\">nnn</font>");
+   
 
-  print '<p class="noprint">';
-  print trackers_field_textarea('details',$details);
-  print '<p>';
+  print '</p>&nbsp;<p>';
 
-  print show_item_details($item_id,$group_id,0,$item_assigned_to);
+  print show_item_details($item_id,$group_id,0,$item_assigned_to,$quotation_style);
 
   print '</p>&nbsp;<p>';
 
@@ -452,12 +478,33 @@ print form_input("hidden", "item_id", $item_id);
     ._("Add an email address that should receive carbon copies of updates of this item:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.$add_cc.'">&nbsp;&nbsp;&nbsp;
         <br />
         <font class="preinput">'
-    ._("Comment:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" value="'.$cc_comment.'">';
+    ._("Comment:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" value="'.$cc_comment.'" />';
   print '<p></p>';
   show_item_cc_list($item_id, $group_id);
 
   print '<p>&nbsp;</p>';
 
+  # ################################ Votes
+
+  if (trackers_data_is_used("vote"))
+    {
+      $votes_given = trackers_votes_user_giventoitem_count(user_getid(), ARTIFACT, $item_id);
+      $votes_remaining = trackers_votes_user_remains_count(user_getid()) + $votes_given;
+      if (!$new_vote) 
+        { $new_vote = $votes_given; }
+
+      # ATM, the mod page is only for technicians/manager. They always have
+      # the right to vote, as they are project member anyway.
+      print '<h3>'.html_anchor(_("Votes"), "votes").'</h3>';
+      print '<p>'.sprintf(ngettext("There is %s vote so far.", "There are %s votes so far.", $votes), $votes).' '._("Votes easily highlight which items people would like to see resolved in priority, independantly of the priority of the item set by tracker managers.").'</p><p class="noprint">';
+       
+      # Show how many vote he already gave and allows to remove or give more
+      # votes.
+      # The number of remaining points must be 100 - others votes
+      print '<font class="preinput">'._("Your vote:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="new_vote" size="3" maxlength="3" value="'.$new_vote.'" /> '.sprintf(ngettext("/ %s remaining vote", "/ %s remaining votes", $votes_remaining), $votes_remaining);
+      print '</p>';
+      print '<p>&nbsp;</p>';
+    }
 
   # ################################ Reassign an item, if manager of the tracker
   if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
