@@ -2,26 +2,26 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: utils.php,v 1.69 2005/03/31 09:00:04 yeupou Exp $
+# $Id: utils.php,v 1.74 2005/08/20 22:16:28 beuc Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
 #  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>,
 #
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 
 # Many functions in this file do not set sys_debug_where, they are too
@@ -80,6 +80,11 @@ function utils_link ($url, $title, $defaultclass=0, $available=1, $help=0)
   return $return;
 }
 
+# Found out if a string is pure ASCII or not
+function utils_is_ascii ($string) 
+{
+  return preg_match('%^(?: [\x09\x0A\x0D\x20-\x7E] )*$%xs', $string);
+}
 
 # Alias function
 function utils_altrow ($i)
@@ -361,32 +366,44 @@ function utils_line_wrap ($text, $wrap = 78, $break = "\n")
   return implode($break, $result);
 }
 
-function utils_make_links ($data='',$group_id = 0)
+function utils_make_links($data='',$group_id = 0)
 {
   # group_id is a deprecated useless parameter.
 
-  if(empty($data))
+  if (empty($data))
     { return $data; }
 
   $lines = split("\n",$data);
-  while ( list ($key,$line) = each ($lines))
+  foreach ($lines as $key => $line)
     {
-      # Don't mess with html links already there
-      $line = eregi_replace("<a href(.*)://(.*)://(.*)</a>","<a href\\1:##\\2:##\\3</a>",$line);
-      $line = eregi_replace("<a href(.*)://(.*)</a>","<a href\\1:##\\2</a>",$line);
+      # Don't mess with HTML links already there by escaping
+      # the protocol separator with ":##"
+      $line = eregi_replace("(<a href=\"[a-z]+)://([^<[:space:]]+)://([^<[:space:]]+)</a>", '\1:##\2:##\3</a>', $line);
+      $line = eregi_replace("(<a href=\"[a-z]+)://([^<\"[:space:]]+)\"", '\1:##\2"', $line);
 
-      # Make usual links
-      $line = eregi_replace("([ \t]|^)www\."," http://www.",$line);
-      # FIXME: and &gt; broke the following regexp, so we do an
-      # ugly convert->work->convert.
-      # Please propose a better regexp.
-      $line = eregi_replace("&gt;", ">--", $line);
-      $line = eregi_replace("(([a-z0-9_]|\\-|\\.)+://([^[:space:]><]*)([[:alnum:]-]))", "<a href=\"\\1\">\\1</a>", $line);
-      $line = eregi_replace("(([a-z0-9_]|\\-|\\.)+@([^[:space:]&><]*)([[:alnum:]-]))", "<a href=\"mailto:\\1\">\\1</a>", $line);
-      $line = eregi_replace(">--", "&gt;", $line);
+      # Make usual links: prefix every "www." with "http://"
+      $line = eregi_replace("(^|[[:space:]]+)www\.","\\1http://www.",$line);
 
-      # Don't mess with html links already there
-      $line = eregi_replace(":##", "://", $line);
+      # replace the @ sign with an HTML entity, if it is used within
+      # an url (e.g. for pointers to mailing lists). This way, the
+      # @ sign doesn't get mangled in the e-mail markup code
+      # below. See bug #2689 on http://gna.org/ for reference.
+      $line = eregi_replace("([a-z]+://[^<>[:space:]]+)@", "\\1&#64;", $line);
+
+      # When detecting URIs, we expect to parse text, not HTML.
+      # That way &lt;http://blabla&gt; (eg <http://blabla>) is
+      # correctly converted (recognised URL is http://blabla and not
+      # http://blabla&gt).
+      $line = html_entity_decode($line);
+
+      # do a markup for normal links, e.g. http://test.org
+      $line = eregi_replace("([a-z]+://[^<>[:space:]]+[a-z0-9/]+)", '<a href="\1">\1</a>', $line);
+
+      # do a markup for mail links, e.g. info@support.org
+      $line = eregi_replace("([a-z0-9_+-.]+@([a-z0-9_+-]+\.)+[a-z]+)", '<a href="mailto:\1">\1</a>', $line);
+
+      # Revert the escaping of already provided HTML links, done above
+      $line = str_replace(":##", "://", $line);
 
       # Links between items
       # FIXME: it should be i18n, but in a clever way, meaning that everytime
@@ -399,12 +416,9 @@ function utils_make_links ($data='',$group_id = 0)
       $line = eregi_replace("patch[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."patch/?func=detailitem&amp;item_id=\\1\" class=\"italic\">patch&nbsp;#\\1</a>", $line);
       $line = eregi_replace("comment[ ]?#([0-9]+)", '<a href="#comment\\1">comment&nbsp;#\\1</a>', $line);
 
-
-
       $lines[$key] = $line;
     }
   return join("\n", $lines);
-
 }
 
 function utils_user_link ($username, $realname=0)
