@@ -2,26 +2,26 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: bookmarks.php,v 1.5 2005/03/20 13:23:22 yeupou Exp $
+# $Id: bookmarks.php,v 1.7 2005/08/03 19:14:04 beuc Exp $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
 #  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
 # 
-# This program is free software; you can redistribute it and/or
+# The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# The Savane project is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# along with the Savane project; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 
 require "../include/pre.php";
@@ -56,7 +56,7 @@ if ($edit)
 	  $title = stripslashes(db_result($result,0,'bookmark_title'));
 	  $url = stripslashes(db_result($result,0,'bookmark_url'));
 	  
-	  print '<form action="'.$PHPSELF.'" method="post">';
+	  print '<form action="'.$_SERVER['PHP_SELF'].'" method="post">';
 	  print '<font class="preinput">'._("Title:").'</font>';
 	  print '<br />&nbsp;&nbsp;&nbsp;<input type="text" name="title" value="'.$title.'" size="50" />';
 	  print '<br />';
